| Field                                                                                                                                  | Response                                       |
| :------------------------------------------------------------------------------------------------------------------------------------- | :--------------------------------------------- |
| Generatable or reverse engineerable personal information?                                                                              | None                                           |
| Protected class data used to create this model?                                                                                        | None                                           |
| Was consent obtained for any personal data used?                                                                                       | Not Applicable (No Personal Data)              |
| How often is dataset reviewed?                                                                                                         | Before Release                                 |
| Is a mechanism in place to honor data subject right of access or deletion of personal data?                                            | Not Applicable                                 |
| If personal collected for the development of the model, was it collected directly by NVIDIA?                                           | Not Applicable                                 |
| If personal collected for the development of the model by NVIDIA, do you maintain or have access to disclosures made to data subjects? | Not Applicable                                 |
| If personal collected for the development of this AI model, was it minimized to only what was required?                                | Not Applicable                                 |
| Is data in dataset traceable?                                                                                                          | Yes                                            |
| Is there provenance for all datasets used in training?                                                                                 | Yes                                            |
| Does data labeling (annotation, metadata) comply with privacy laws?                                                                    | Yes                                            |
| Is data compliant with data subject requests for data correction or removal, if such a request was made?                               | No, not possible with externally-sourced data. |
